
.. |OrbDot Logo Light| image:: https://github.com/simonehagey/orbdot/blob/main/docs/source/_static/orbdot_logo.png?raw=true#gh-light-mode-only
   :width: 310px

.. |OrbDot Logo Dark| image:: https://github.com/simonehagey/orbdot/blob/main/docs/source/_static/orbdot_logo_dark.png?raw=true#gh-dark-mode-only
   :width: 310px

.. |JOSS Status| image:: https://joss.theoj.org/papers/a7fb37729237dec9e965d7ee38cfd2ee/status.svg
   :target: https://joss.theoj.org/papers/a7fb37729237dec9e965d7ee38cfd2ee

.. |License Information| image:: https://img.shields.io/badge/license-MIT-blue.svg
   :target: https://github.com/simonehagey/orbdot/blob/main/LICENSE

.. |Documentation Status| image:: https://readthedocs.org/projects/orbdot/badge/?version=latest
   :target: https://orbdot.readthedocs.io/

.. |Test Status| image:: https://github.com/simonehagey/orbdot/actions/workflows/test.yaml/badge.svg
   :target: https://github.com/simonehagey/orbdot/actions/workflows/test.yaml

.. |PyPi Version| image:: https://img.shields.io/pypi/v/orbdot?label=pypi%20package
   :target: https://pypi.org/project/orbdot/1.0.0rc1/

.. |Zenodo Badge| image:: https://zenodo.org/badge/802446381.svg
   :target: https://doi.org/10.5281/zenodo.15346681

|OrbDot Logo Light|
|OrbDot Logo Dark|

:Contact: Simone R. Hagey (shagey@phas.ubc.ca)

|JOSS Status| |License Information| |Zenodo Badge|
|Documentation Status| |Test Status| |PyPi Version|

==================
Welcome to OrbDot!
==================
OrbDot is a Python package for studying the secular (long-term) evolution of exoplanet orbits using observational data. Using nested sampling algorithms, it fits evolutionary models using any combination of transit and eclipse timing, radial velocities, and transit durations.

In addition to model fitting, OrbDot offers tools for interpreting results, generating reports on model comparisons, derived tidal decay parameters, predicted precession rates, implications for planetary companions, and more.

Comprehensive documentation, including examples, is available on `Read the Docs <https://orbdot.readthedocs.io/>`__.

Installation
============
For installation instructions and dependency requirements, see the `installation guide <https://orbdot.readthedocs.io/en/latest/installation.html>`__.

Citing OrbDot
=============
If you use OrbDot in your research, please refer to the `citation instructions <https://orbdot.readthedocs.io/en/latest/citing-orbdot.html>`__.

Contributing to OrbDot
======================
Feedback, bug reports, feature requests, and code contributions are welcome! Please refer to the `contributing guidelines <https://orbdot.readthedocs.io/en/latest/community_guidelines.html>`__ for more information.

-----

TrES-1 b Case Study
===================
In addition to the documentation, there is a complementary `TrES-1 b case study <https://arxiv.org/abs/2508.15075>`__ that showcases the full functionality of OrbDot’s model-fitting and interpretive tools, while providing a deeper dive into the theoretical foundations behind the package. This paper consolidates key equations in one place, making it a valuable reference for researchers looking to apply OrbDot to their own work.


